@@ -9,6 +9,7 @@
 
 
 #include <KAboutData>
+#include <KCrash>
 
 #include <QApplication>
 #include <KLocalizedString>
@@ -30,7 +31,7 @@ int main(int argc, char *argv[])
     migrate.migrate();
 
     KAboutData aboutData("kollision", i18n("Kollision"),
-                         "0.2", i18n("KDE collision game"), KAboutLicense::GPL,
+                         "0.3", i18n("KDE collision game"), KAboutLicense::GPL,
                          i18n("(c) 2007 Paolo Capriotti"));
     aboutData.addAuthor(i18n("Paolo Capriotti"), QString(), "p.capriotti@gmail.com");
     aboutData.addAuthor(i18n("Dmitry Suzdalev"), QString(), "dimsuz@gmail.com");
@@ -43,6 +44,7 @@ int main(int argc, char *argv[])
 
     QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
+    KCrash::initialize();
     parser.addVersionOption();
     parser.addHelpOption();
     aboutData.setupCommandLine(&parser);
